@@ -38,7 +38,7 @@ PCA_plot <- function(count_data, metadata, variable, color, response_variable="M
 
   }
 
-  if(identical(as.character(colnames(count_data)[unlist(lapply(count_data, is.numeric))]), as.character(metadata$Sample))==FALSE){
+  if(identical(sort(as.character(colnames(count_data)[unlist(lapply(count_data, is.numeric))])), sort(as.character(metadata$Sample))==FALSE)){
 
     stop("Sample names in count_data and metadata do not match.")
 
